@@ -1,12 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 1999-2006 by Éric Bischoff <ebischoff@nerim.net>        *
- *   Copyright (C) 2007 by Albert Astals Cid <aacid@kde.org>               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 1999-2006 Éric Bischoff <ebischoff@nerim.net>
+    SPDX-FileCopyrightText: 2007 Albert Astals Cid <aacid@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /* Top level window */
 
@@ -25,6 +22,7 @@
 #include <KSharedConfig>
 #include <kio/job.h>
 
+#include <QActionGroup>
 #include <QApplication>
 #include <QClipboard>
 #include <QFileDialog>
@@ -44,7 +42,7 @@ static const char *DEFAULT_THEME = "default_theme.theme";
 
 // Constructor
 TopLevel::TopLevel()
-  : KXmlGuiWindow(0)
+  : KXmlGuiWindow(nullptr)
 {
   QString board, language;
 
@@ -276,9 +274,9 @@ void TopLevel::setupKAction()
   action = KStandardAction::copy(this, &TopLevel::editCopy, actionCollection());
   actionCollection()->addAction(action->objectName(), action);
 
-  action = KStandardAction::undo(0, 0, actionCollection());
+  action = KStandardAction::undo(nullptr, nullptr, actionCollection());
   playGround->connectUndoAction(action);
-  action = KStandardAction::redo(0, 0, actionCollection());
+  action = KStandardAction::redo(nullptr, nullptr, actionCollection());
   playGround->connectRedoAction(action);
 
   //Speech
